API reference
====================

.. automodule:: flightplandb
   :members:
   :undoc-members:
   :show-inheritance:

.. toctree::
   :maxdepth: 5

   api
   nav
   plan
   tags
   user
   weather
   datatypes
   exceptions
   internal
